``` bash
svn export https://github.com/fetchai/agents-aea.git/trunk/examples
svn export https://github.com/fetchai/agents-aea.git/trunk/packages
```
``` bash
pip install numpy gym
```
``` bash
python examples/gym_ex/train.py
```
